@@ -81,18 +81,37 @@ def _cloudstack_volume_to_gce(cloudstack_response, projectid, zone):
     return response
 
 
-@app.route(
-    '/' + app.config['PATH'] + '<projectid>/aggregated/disks', methods=['GET'])
+@app.route('/compute/v1/projects/<projectid>/aggregated/disks', methods=['GET'])
 @authentication.required
 def aggregatedlistdisks(projectid, authorization):
     disk_list = _get_disks(authorization=authorization)
     zone_list = zones.get_zone_names(authorization=authorization)
 
+    disk = None
+    filter = helper.get_filter(request.args)
+
+    if 'name' in filter:
+        disk = filter['name']
+
     items = {}
 
     for zone in zone_list:
         zone_disks = []
-        if disk_list['listvolumesresponse']:
+        if disk:
+            disk = get_disk_by_name(
+                authorization=authorization,
+                disk=disk
+            )
+            if disk:
+                zone_disks.append(
+                    _cloudstack_volume_to_gce(
+                        cloudstack_response=disk,
+                        projectid=projectid,
+                        zone=zone,
+                    )
+                )
+
+        elif disk_list['listvolumesresponse']:
             for disk in disk_list['listvolumesresponse']['volume']:
                 zone_disks.append(
                     _cloudstack_volume_to_gce(
@@ -102,7 +121,6 @@ def aggregatedlistdisks(projectid, authorization):
                     )
                 )
         items['zone/' + zone] = {}
-        items['zone/' + zone]['zone'] = zone
         items['zone/' + zone]['disks'] = zone_disks
 
     populated_response = {
@@ -115,8 +133,7 @@ def aggregatedlistdisks(projectid, authorization):
     return helper.create_response(data=populated_response)
 
 
-@app.route('/' + app.config['PATH'] +
-           '<projectid>/zones/<zone>/disks', methods=['GET'])
+@app.route('/compute/v1/projects/<projectid>/zones/<zone>/disks', methods=['GET'])
 @authentication.required
 def listdisks(projectid, authorization, zone):
     disk = None
@@ -167,11 +184,7 @@ def listdisks(projectid, authorization, zone):
     return helper.create_response(data=populated_response)
 
 
-@app.route(
-    '/' +
-    app.config['PATH'] +
-    '<projectid>/zones/<zone>/disks/<disk>',
-    methods=['GET'])
+@app.route('/compute/v1/projects/<projectid>/zones/<zone>/disks/<disk>', methods=['GET'])
 @authentication.required
 def getdisk(projectid, authorization, zone, disk):
     response = get_disk_by_name(
