@@ -118,10 +118,11 @@ def _cloudstack_virtual_machine_to_gce(cloudstack_response, zone, projectid):
     response['disks'] = []
 
     networking = {}
-    networking['network'] = cloudstack_response['securitygroup'][0]['name']
-    networking['networkIP'] = cloudstack_response['nic'][0]['ipaddress']
-    networking['name'] = cloudstack_response['nic'][0]['id']
-    networking['accessConfigs'] = []
+    if cloudstack_response['securitygroup']:
+        networking['network'] = cloudstack_response['securitygroup'][0]['name']
+        networking['networkIP'] = cloudstack_response['nic'][0]['ipaddress']
+        networking['name'] = cloudstack_response['nic'][0]['id']
+        networking['accessConfigs'] = []
 
     accessconfig = {}
     accessconfig['kind'] = 'compute#accessConfig'
@@ -129,7 +130,7 @@ def _cloudstack_virtual_machine_to_gce(cloudstack_response, zone, projectid):
     accessconfig['name'] = 'External NAT'
     accessconfig['natIP'] = cloudstack_response['nic'][0]['ipaddress']
 
-    networking['accessConfigs'].append(accessconfig)
+    networking['accessConfigs'] = accessconfig
 
     response['networkInterfaces'].append(networking)
 
@@ -163,23 +164,39 @@ def _get_virtual_machine_by_name(authorization, instance):
         return None
 
 
-@app.route(
-    '/' +
-    app.config['PATH'] +
-    '<projectid>/aggregated/instances',
-    methods=['GET'])
+@app.route('/compute/v1/projects/<projectid>/aggregated/instances', methods=['GET'])
 @authentication.required
 def aggregatedlistinstances(authorization, projectid):
     zone_list = zones.get_zone_names(authorization=authorization)
     virtual_machine_list = _get_virtual_machines(authorization=authorization)
 
+    instance = None
+    filter = helper.get_filter(request.args)
+
+    if 'name' in filter:
+        instance = filter['name']
+
     items = {}
 
     for zone in zone_list:
-        zones_instances = []
-        if virtual_machine_list['listvirtualmachinesresponse']:
+        zone_instances = []
+        if instance:
+            virtual_machine = _get_virtual_machine_by_name(
+                authorization=authorization,
+                instance=instance
+            )
+            if virtual_machine:
+                zone_instances.append(
+                    _cloudstack_virtual_machine_to_gce(
+                        cloudstack_response=virtual_machine,
+                        projectid=projectid,
+                        zone=zone
+                    )
+                )
+
+        elif virtual_machine_list['listvirtualmachinesresponse']:
             for instance in virtual_machine_list['listvirtualmachinesresponse']['virtualmachine']:
-                zones_instances.append(
+                zone_instances.append(
                     _cloudstack_virtual_machine_to_gce(
                         cloudstack_response=instance,
                         projectid=projectid,
@@ -187,8 +204,7 @@ def aggregatedlistinstances(authorization, projectid):
                     )
                 )
         items['zone/' + zone] = {}
-        items['zone/' + zone]['zone'] = zone
-        items['zone/' + zone]['instances'] = zones_instances
+        items['zone/' + zone]['instances'] = zone_instances
 
     populated_response = {
         'kind': 'compute#instanceAggregatedList',
@@ -199,11 +215,7 @@ def aggregatedlistinstances(authorization, projectid):
     return helper.create_response(data=populated_response)
 
 
-@app.route(
-    '/' +
-    app.config['PATH'] +
-    '<projectid>/zones/<zone>/instances',
-    methods=['GET'])
+@app.route('/compute/v1/projects/<projectid>/zones/<zone>/instances', methods=['GET'])
 @authentication.required
 def listinstances(authorization, projectid, zone):
     instance = None
@@ -250,11 +262,7 @@ def listinstances(authorization, projectid, zone):
     return helper.create_response(data=populated_response)
 
 
-@app.route(
-    '/' +
-    app.config['PATH'] +
-    '<projectid>/zones/<zone>/instances/<instance>',
-    methods=['GET'])
+@app.route('/compute/v1/projects/<projectid>/zones/<zone>/instances/<instance>', methods=['GET'])
 @authentication.required
 def getinstance(projectid, authorization, zone, instance):
     response = _get_virtual_machine_by_name(
@@ -278,18 +286,15 @@ def getinstance(projectid, authorization, zone, instance):
         return errors.resource_not_found(function_route)
 
 
-@app.route(
-    '/' +
-    app.config['PATH'] +
-    '<projectid>/zones/<zone>/instances',
-    methods=['POST'])
+@app.route('/compute/v1/projects/<projectid>/zones/<zone>/instances', methods=['POST'])
 @authentication.required
 def addinstance(authorization, projectid, zone):
     data = json.loads(request.data)
+    print data
     args = {}
     args['name'] = data['name']
     args['serviceoffering'] = data['machineType'].rsplit('/', 1)[1]
-    args['template'] = data['image'].rsplit('/', 1)[1]
+    args['template'] = data['disks'][0]['initializeParams']['sourceImage'].rsplit('/', 1)[1]
     args['zone'] = zone
 
     network = data['networkInterfaces'][0]['network'].rsplit('/', 1)[1]
@@ -324,11 +329,7 @@ def addinstance(authorization, projectid, zone):
     return helper.create_response(data=populated_response)
 
 
-@app.route(
-    '/' +
-    app.config['PATH'] +
-    '<projectid>/zones/<zone>/instances/<instance>',
-    methods=['DELETE'])
+@app.route('/compute/v1/projects/<projectid>/zones/<zone>/instances/<instance>', methods=['DELETE'])
 @authentication.required
 def deleteinstance(projectid, authorization, zone, instance):
     deletion_result = _destroy_virtual_machine(authorization, instance)
